OC.L10N.register(
    "files",
    {
    "File could not be found" : "Non foi posíbel atopar o ficheiro",
    "Move or copy" : "Mover ou copiar",
    "Download" : "Descargar",
    "Delete" : "Eliminar",
    "Tags" : "Etiquetas",
    "Show list view" : "Amosar a vista de lista",
    "Show grid view" : "Amosar a vista de grade",
    "Home" : "Inicio",
    "Close" : "Pechar",
    "Could not create folder \"{dir}\"" : "Non foi posíbel crear o cartafol «{dir}»",
    "This will stop your current uploads." : "Isto deterá os envíos actuais.",
    "Upload cancelled." : "Envío cancelado.",
    "Processing files …" : "Procesando ficheiros…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Non é posíbel enviar {filename}, xa que ou é un directorio ou ten 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Non hai espazo libre abondo, o seu envío é de {size1} mais só dispón de {size2}",
    "Target folder \"{dir}\" does not exist any more" : "O cartafol de destino «{dir}» xa non existe",
    "Not enough free space" : "Non hai espazo libre abondo",
    "An unknown error has occurred" : "Produciuse un erro descoñecido",
    "File could not be uploaded" : "Non foi posíbel enviar o ficheiro",
    "Uploading …" : "Enviando…",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Enviando… ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Non se admite o envío deste elemento",
    "Target folder does not exist any more" : "O cartafol de destino xa non existe",
    "Operation is blocked by access control" : "A operación está a se bloqueda polo control de acceso",
    "Error when assembling chunks, status code {status}" : "Produciuse un erro ao ensamblar os bloques, código de estado {status}",
    "Actions" : "Accións",
    "Rename" : "Renomear",
    "Move" : "Mover",
    "Copy" : "Copiar",
    "Choose target folder" : "Escoller o cartafol de destino",
    "Set reminder" : "Definir un lembrete",
    "Edit locally" : "Editar localmente",
    "Open" : "Abrir",
    "_Delete file_::_Delete files_" : ["Eliminar ficheiro","Eliminar ficheiros"],
    "Could not load info for file \"{file}\"" : "Non foi posíbel cargar información para o ficheiro «{file}»",
    "Files" : "Ficheiros",
    "Details" : "Detalles",
    "Please select tag(s) to add to the selection" : "Escolla a etiqueta(s) para engadir á selección",
    "Apply tag(s) to selection" : "Aplicar etiqueta(s) á selección",
    "Select directory \"{dirName}\"" : "Seleccione o directorio «{dirName}»",
    "Select file \"{fileName}\"" : "Seleccione o ficheiro «{fileName}»",
    "Pending" : "Pendentes",
    "Unable to determine date" : "Non é posíbel determinar a data",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Este directorio non está dispoñíbel, comprobe os rexistros ou póñase en contacto coa administración desta instancia.",
    "Storage is temporarily not available" : "O almacenamento non está dispoñíbel temporalmente",
    "Could not move \"{file}\", target exists" : "Non foi posíbel mover «{file}», o destino xa existe",
    "Could not move \"{file}\"" : "Non foi posíbel mover «{file}»",
    "copy" : "copiar",
    "Could not copy \"{file}\", target exists" : "Non foi posíbel copiar «{file}», o destino xa existe",
    "Could not copy \"{file}\"" : "Non foi posíbel copiar «{file}",
    "Copied {origin} inside {destination}" : "Copiado {origin} en {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiado {origin} e outros {nbfiles} ficheiros en {destination} ",
    "Failed to redirect to client" : "Produciuse un fallo ao redirixir ao cliente",
    "{newName} already exists" : "Xa existe {newName}",
    "Could not rename \"{fileName}\", it does not exist any more" : "Non foi posíbel renomear «{fileName}», xa non existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome «{targetName}» xa se utiliza no cartafol «{dir}». Escolla outro nome.",
    "Could not rename \"{fileName}\"" : "Non foi posíbel renomear «{fileName}»",
    "Could not create file \"{file}\"" : "Non foi posíbel crear o ficheiro «{file}»",
    "Could not create file \"{file}\" because it already exists" : "Non foi posíbel crear o ficheiro «{file}» por mor de que xa existe",
    "Could not create folder \"{dir}\" because it already exists" : "Non foi posíbel crear o cartafol «{dir}» por mor de que xa existe",
    "Could not fetch file details \"{file}\"" : "Non foi posíbel recuperar os detalles do ficheiro «{file}»",
    "Error deleting file \"{fileName}\"." : "Produciuse un erro ao eliminar o ficheiro «{fileName}».",
    "No search results in other folders for {tag}{filter}{endtag}" : "Non foi posíbel atopar resultados de busca noutros cartafoles para {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Introduza máis de dous caracteres para buscar noutros cartafoles",
    "Name" : "Nome",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n cartafol","%n cartafoles"],
    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluíndo %n agachado","incluíndo %n agochados"],
    "You do not have permission to upload or create files here" : "Non ten permiso para enviar ou crear ficheiros aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Enviando %n ficheiro","Enviando %n ficheiros"],
    "New" : "Novo",
    "New file/folder menu" : "Novo menú ficheiro/cartafol",
    "Select file range" : "Seleccionar o intervalo de ficheiros ",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "Usados {used} de {quota}",
    "{used} used" : "{used} usados",
    "\"{name}\" is an invalid file name." : "«{name}» é un nome incorrecto de ficheiro.",
    "File name cannot be empty." : "O nome de ficheiro non pode estar baleiro",
    "\"/\" is not allowed inside a file name." : "«/» non está permitido nun nome de ficheiro",
    "\"{name}\" is not an allowed filetype" : "«{name}» non é un tipo de ficheiro permitido",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "O espazo de almacenamento de {owner} está cheo, xa é posíbel actualizar nin sincronizar os ficheiros!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "O cartafol «{mountPoint}» do grupo está completo, non se poderán actualizar nin sincronizar ficheiros!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "O almacenamento externo «{mountPoint}» está cheo, xa non é posíbel actualizar nin sincronizar os ficheiros.",
    "Your storage is full, files cannot be updated or synced anymore!" : "O seu espazo de almacenamento está cheo, xa non é posíbel actualizar nin sincronizar os ficheiros!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "O espazo de almacenamento de {owner} está case cheo ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "O cartafol de grupo «{mountPoint}» está case cheo ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "O almacenamento externo «{mountPoint}» está case cheo ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)." : "O seu espazo de almacenamento está case cheo ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincide con «{filter}»","coinciden con «{filter}»"],
    "View in folder" : "Ver no cartafol",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Marcado como favorito",
    "Favorite" : "Favorito",
    "New folder" : "Novo cartafol",
    "Create new folder" : "Crear un cartafol novo",
    "Upload file" : "Enviar ficheiro",
    "Recent" : "Recente",
    "Not favorited" : "Non marcado como favorito",
    "Remove from favorites" : "Retirar de favoritos",
    "Add to favorites" : "Engadir a favoritos",
    "An error occurred while trying to update the tags" : "Produciuse un erro ao tentar actualizar as etiquetas",
    "Added to favorites" : "Engadido a favoritos",
    "Removed from favorites" : "Retirado de favoritos",
    "You added {file} to your favorites" : "Engadiu {file} aos seus favoritos",
    "You removed {file} from your favorites" : "Retirou {file} dos seus favoritos",
    "Favorites" : "Favoritos",
    "File changes" : "Cambios do ficheiro",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Cambiado por {user}",
    "Deleted by {user}" : "Eliminado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renomeado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "You created {file}" : "{file} foi creado por Vde.",
    "You created an encrypted file in {file}" : "Vde. creo un ficheiro cifrado en {file}",
    "{user} created {file}" : "{user} creou {file}",
    "{user} created an encrypted file in {file}" : "{user} creou un ficheiro cifrado en {file}",
    "{file} was created in a public folder" : "{file} foi creado nun cartafol público",
    "You changed {file}" : "{file} foi cambiado por Vde.",
    "You changed an encrypted file in {file}" : "Vde. cambiou un ficheiro cifrado en {file}",
    "{user} changed {file}" : "{file} foi cambiado por {user}",
    "{user} changed an encrypted file in {file}" : "{user} cambiou un ficheiro cifrado en {file}",
    "You deleted {file}" : "{file} foi eliminado por Vde.",
    "You deleted an encrypted file in {file}" : "Vde. eliminou un ficheiro cifrado en {file}",
    "{user} deleted {file}" : "{file} foi eliminado por {user}",
    "{user} deleted an encrypted file in {file}" : "{user} eliminou un ficheiro cifrado en {file}",
    "You restored {file}" : "{file} foi restaurado por Vde.",
    "{user} restored {file}" : "{file} foi restaurado por {user}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Vde. renomeou {oldfile} (agochado) como {newfile} (agochado)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Vde. renomeou {oldfile} (agochado) como {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Vde. renomeou {oldfile} como {newfile} (agochado)",
    "You renamed {oldfile} to {newfile}" : "Vde. renomeou {oldfile} como {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} renomeou {oldfile} (agochado) como {newfile} (agochado)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} renomeou {oldfile} (agochado) como {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} renomeou {oldfile} como {newfile} (agochado)",
    "{user} renamed {oldfile} to {newfile}" : "{user} renomeou {oldfile} como {newfile}",
    "You moved {oldfile} to {newfile}" : "Vde. moveu {oldfile} para {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moveu {oldfile} para {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Engadiuse ou retirouse un ficheiro dos seus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong>" : "<strong>Cambiouse</strong> un ficheiro ou cartafol",
    "A favorite file or folder has been <strong>changed</strong>" : "<strong>Cambiouse</strong> un ficheiro ou cartafol favorito",
    "Upload (max. %s)" : "Envío (máx. %s)",
    "Accept" : "Aceptar",
    "Reject" : "Rexeitar",
    "Incoming ownership transfer from {user}" : "Transferencia da propiedade entrante de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Quere aceptar {path}?\n\nNota: Ao proceso de transferencia após aceptar pode levarlle ata 1 hora.",
    "Ownership transfer failed" : "Produciuse un fallo na transferencia da propiedade",
    "Your ownership transfer of {path} to {user} failed." : "Produciuse un fallo na súa transferencia da propiedade de {path} cara a {user}.",
    "The ownership transfer of {path} from {user} failed." : "Produciuse un fallo na transferencia da propiedade de {path} cara a {user}.",
    "Ownership transfer done" : "Feita a transferencia da propiedade",
    "Your ownership transfer of {path} to {user} has completed." : "Completouse a súa transferencia da propiedade de {path} cara a {user}.",
    "The ownership transfer of {path} from {user} has completed." : "Completouse a transferencia da propiedade de {path} cara a {user}.",
    "in %s" : "en %s",
    "File Management" : "Xestión de ficheiros",
    "Reload current directory" : "Recargar o directorio actual",
    "Go to the \"{dir}\" directory" : "Vaia ao directorio «{dir}».",
    "Drag and drop files here to upload" : "Arrastre e solte os ficheiros aquí para envialos",
    "Your have used your space quota and cannot upload files anymore" : "Vde. usou a súa cota de espazo e xa non pode enviar ningún ficheiro más",
    "You don’t have permission to upload or create files here" : "Non ten permiso para enviar ou crear ficheiros aquí.",
    "\"{displayName}\" action executed successfully" : "A acción «{displayName}» executouse correctamente",
    "\"{displayName}\" action failed" : "A acción «{displayName}» fallou",
    "Rename file" : "Renomear o ficheiro",
    "File name" : "Nome de ficheiro",
    "Folder name" : "Nome do cartafol",
    "This node is unavailable" : "Este nodo non está dispoñíbel",
    "Download file {name}" : "Descargar o ficheiro {name}",
    "\"{name}\" is not an allowed filetype." : "«{name}» non é un tipo de ficheiro permitido.",
    "{newName} already exists." : "Xa existe {newName}",
    "\"{char}\" is not allowed inside a file name." : "«{char}» non está permitido nun nome de ficheiro.",
    "Name cannot be empty" : "O nome non pode estar baleiro",
    "Another entry with the same name already exists" : "Xa existe outra entrada co mesmo nome",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Cambiouse o nome de «{oldName}» a «{newName}»",
    "Could not rename \"{oldName}\", it does not exist any more" : "Non foi posíbel renomear «{oldName}», xa non existe",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome «{newName}» xa se utiliza no cartafol «{dir}». Escolla un nome diferente.",
    "Could not rename \"{oldName}\"" : "Non foi posíbel renomear «{oldName}»",
    "Total rows summary" : "Resumo total de filas",
    "\"{displayName}\" failed on some elements " : "Produciuse un fallo nalgúns elementos de «{displayName}» ",
    "\"{displayName}\" batch action executed successfully" : "A acción por lotes «{displayName}» executouse correctamente",
    "List of files and folders." : "Lista de ficheiros e cartafoles",
    "Column headers with buttons are sortable." : "As cabeceiras das columnas con botóns pódense ordenar.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta lista non se representa de xeito completo por mor do rendemento. Os ficheiros represéntanse mentres se despraza pola lista.",
    "File not found" : "Ficheiro non atopado",
    "Storage informations" : "Información de almacenamento",
    "{usedQuotaByte} used" : "{usedQuotaByte} usado",
    "{relative}% used" : "{relative}% usado",
    "Could not refresh storage stats" : "Non foi posíbel  actualizar as estatísticas de almacenamento",
    "Your storage is full, files can not be updated or synced anymore!" : "O seu espazo de almacenamento está cheo, xa non se poden actualizar nin sincronizar os ficheiros.",
    "Create" : "Crear",
    "Transfer ownership of a file or folder" : "Transferencia da propiedade dun ficheiro ou cartafol",
    "Choose file or folder to transfer" : "Escolla o ficheiro ou cartafol para transferir",
    "Change" : "Cambiar",
    "New owner" : "Novo propietario",
    "Choose a file or folder to transfer" : "Escolla un ficheiro ou cartafol para transferir",
    "Transfer" : "Transferencia",
    "Transfer {path} to {userid}" : "Transferir {path} cara a {userid}",
    "Invalid path selected" : "Seleccionou unha ruta incorrecta.",
    "Unknown error" : "Produciuse un erro descoñecido",
    "Ownership transfer request sent" : "Enviouse solicitude de transferencia da propiedade",
    "Cannot transfer ownership of a file or folder you do not own" : "Non é posíbel transferir a propiedade dun ficheiro ou cartafol do que non es o propietario",
    "Select file or folder to link to" : "Seleccione o ficheiro ou cartafol ao que ligar",
    "Choose file" : "Escoller o ficheiro",
    "Choose {file}" : "Escoller  {file}",
    "Loading current folder" : "Cargando o cartafol actual",
    "No files in here" : "Aquí non hai ficheiros",
    "Upload some content or sync with your devices!" : "Envíe algún contido ou sincronice cos seus dispositivos!",
    "Go to the previous folder" : "Ir ao cartafol anterior",
    "Go back" : "Volver",
    "Share" : "Compartir",
    "Shared by link" : "Compartido por ligazón",
    "Shared" : "Compartido",
    "Switch to list view" : "Cambiar á vista de lista",
    "Switch to grid view" : "Cambiar á vista de grade",
    "Error during upload: {message}" : "Produciuse un erro durante o envío: {message}",
    "Unknown error during upload" : "Produciuse un erro descoñecido durante o envío",
    "Open the files app settings" : "Abrir os axustes da aplicación de ficheiros",
    "Files settings" : "Axustes de Ficheiros",
    "File cannot be accessed" : "Non é posíbel acceder ao ficheiro",
    "Sort favorites first" : "Ordene antes os favoritos",
    "Show hidden files" : "Amosar os ficheiros agochados",
    "Crop image previews" : "Recortar a vista previa das imaxes",
    "Enable the grid view" : "Activar á vista de grade",
    "Additional settings" : "Axustes adicionais",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "URL de WebDAV",
    "Copy to clipboard" : "Copiar no portapapeis.",
    "Use this address to access your Files via WebDAV" : "Empregue este enderezo para acceder ao seu Ficheiros mediante WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se activou A2F, debe crear e utilizar un novo contrasinal de aplicación premendo aquí.",
    "Clipboard is not available" : "O portapapeis non está dispoñíbel",
    "WebDAV URL copied to clipboard" : "O URL de WebDAV foi copiado no portapapeis",
    "Unable to change the favourite state of the file" : "Non é posíbel cambiar o estado favorito do ficheiro",
    "Error while loading the file data" : "Produciuse un erro ao cargar os datos do ficheiro",
    "Pick a template for {name}" : "Escolla un modelo para {name}",
    "Create a new file with the selected template" : "Crear un novo ficheiro co modelo seleccionado",
    "Creating file" : "Creando o ficheiro",
    "Blank" : "Baleiro",
    "Unable to create new file from template" : "Non é posíbel crear un novo ficheiro a partir do modelo",
    "Delete permanently" : "Eliminar definitivamente",
    "Confirm deletion" : "Confirmar a eliminación",
    "Cancel" : "Cancelar",
    "Destination is not a folder" : "O destino non é un cartafol",
    "This file/folder is already in that directory" : "Este ficheiro/cartafol xa está nese directorio",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Non é posíbel mover un ficheiro/cartafol sobre si mesmo ou a un subcartafol de si mesmo",
    "A file or folder with that name already exists in this folder" : "Neste cartafol xa existe un ficheiro ou cartafol con ese nome",
    "The file does not exist anymore" : "O ficheiro xa non existe",
    "Copy to {target}" : "Copiar en {target}",
    "Move to {target}" : "Mover a {target}",
    "Cancelled move or copy operation" : "Foi cancelada a operación de movemento ou copia",
    "Open folder {displayName}" : "Abrir o cartafol  {displayName}",
    "Open in Files" : "Abrir en Ficheiros",
    "Open details" : "Abrir detalles",
    "Could not copy {file}. {message}" : "Non foi posíbel copiar {file}. {mensaxe}",
    "Could not move {file}. {message}" : "Non foi posíbel mover {file}. {mensaxe}",
    "Created new folder \"{name}\"" : "Creouse un novo cartafol «{name}»",
    "Filename" : "Nome de ficheiro",
    "Unable to initialize the templates directory" : "Non é posíbel iniciar o directorio de modelos",
    "Create new templates folder" : "Crear un novo cartafol de modelos",
    "Templates" : "Modelos",
    "One of the dropped files could not be processed" : "Non foi posíbel procesar un dos ficheiros arrastrados",
    "Uploading \"{filename}\" failed" : "Produciuse un fallo ao cargar «{filename}».",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartafol","{folderCount} cartafoles"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ficheiro","{fileCount} ficheiros"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 ficheiro e {folderCount} cartafol","1 ficheiro e {folderCount} cartafoles"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} ficheiro e 1 cartafol","{fileCount} ficheiros e 1 cartafol"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} ficheiros e {folderCount} cartafoles",
    "List of favorites files and folders." : "Lista de ficheiros e cartafoles favoritos.",
    "No favorites yet" : "Aínda non hai favoritos",
    "Files and folders you mark as favorite will show up here" : "Os ficheiros e cartafoles que marque como favoritos amosaranse aquí",
    "All files" : "Todos os ficheiros",
    "List of your files and folders." : "Lista dos seus ficheiros e cartafoles",
    "List of recently modified files and folders." : "Lista de ficheiros e cartafoles modificados recentemente.",
    "No recently modified files" : "Non hai ficheiros modificados recentemente",
    "Files and folders you recently modified will show up here." : "Os ficheiros e cartafoles que modificou recentemente amosaranse aquí.",
    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Envío grande de máis",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que tenta enviar exceden do tamaño máximo permitido neste servidor",
    "Text file" : "Ficheiro de texto",
    "New text file.txt" : "Novo ficheiro de texto.txt",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Foi copiada a ligazón directa (só funciona para os usuarios que teñen acceso a este ficheiro/cartafol)",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar a ligazón directa (só funciona para usuarios con acceso a este ficheiro/cartafol)",
    "You can only favorite a single file or folder at a time" : "Só pode marcar como favorito un único ficheiro ou cartafol por vez",
    "\"remote user\"" : "«usuario remoto»",
    "Search users" : "Buscar usuarios",
    "You might not have have permissions to view it, ask the sender to share it" : "É posíbel que non teña permisos para velo, pídalle ao remitente que o comparta",
    "Set up templates folder" : "Estabelecer un cartafol de modelos",
    "Toggle %1$s sublist" : "Alternar %1$s sublista",
    "Toggle grid view" : "Alternar a vista como grade",
    "Deleted files" : "Ficheiros eliminados",
    "Shares" : "Comparticións",
    "Shared with others" : "Compartido con outros",
    "Shared with you" : "Compartido con Vde.",
    "Deleted shares" : "Comparticións eliminadas",
    "Pending shares" : "Comparticións pendentes",
    "This file has the tag {tag}" : "Este ficheiro ten a etiqueta {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Este ficheiro ten as etiquetas {firstTags} e {lastTag}",
    "Select the row for {displayName}" : "Seleccione a fila para {displayName}",
    "Open folder {name}" : "Abrir o cartafol {name}",
    "Unselect all" : "Desmarcar todo",
    "ascending" : "ascendente",
    "descending" : "descendente",
    "Sort list by {column} ({direction})" : "Ordenar a lista por {column} ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Esta lista non se representa de xeito completo por mor do rendemento. Os ficheiros represéntanse se despraza pola lista.",
    "Search for an account" : "Buscar por unha conta",
    "Choose" : "Escoller",
    "No files or folders have been deleted yet" : "Aínda non se eliminou ningún ficheiro nin cartafol",
    "Add" : "Engadir",
    "The files is locked" : "Os ficheiros están bloqueados"
},
"nplurals=2; plural=(n != 1);");
